All of lore.kernel.org
 help / color / mirror / Atom feed
From: Lucas De Marchi <lucas.demarchi@intel.com>
To: intel-gfx@lists.freedesktop.org
Cc: Lucas De Marchi <lucas.demarchi@intel.com>
Subject: [PATCH 7/7] drm/i915: rename dpll_info to intel_dpll_info
Date: Mon, 19 Mar 2018 23:24:23 -0700	[thread overview]
Message-ID: <20180320062423.9166-8-lucas.demarchi@intel.com> (raw)
In-Reply-To: <20180320062423.9166-1-lucas.demarchi@intel.com>

Now that the struct is moved to the header, let's add the proper prefix.

git grep -lz "struct dpll_info"  -- drivers/gpu/drm/i915/ | \
	xargs -0 sed -i 's/struct dpll_info/struct intel_dpll_info/g'

Signed-off-by: Lucas De Marchi <lucas.demarchi@intel.com>
---
 drivers/gpu/drm/i915/intel_dpll_mgr.c | 16 ++++++++--------
 drivers/gpu/drm/i915/intel_dpll_mgr.h |  6 +++---
 2 files changed, 11 insertions(+), 11 deletions(-)

diff --git a/drivers/gpu/drm/i915/intel_dpll_mgr.c b/drivers/gpu/drm/i915/intel_dpll_mgr.c
index 436fca8efe8c..3fec3cfdc6af 100644
--- a/drivers/gpu/drm/i915/intel_dpll_mgr.c
+++ b/drivers/gpu/drm/i915/intel_dpll_mgr.c
@@ -1882,7 +1882,7 @@ static void intel_ddi_pll_init(struct drm_device *dev)
 }
 
 struct intel_dpll_mgr {
-	const struct dpll_info *dpll_info;
+	const struct intel_dpll_info *dpll_info;
 
 	struct intel_shared_dpll *(*get_dpll)(struct intel_crtc *crtc,
 					      struct intel_crtc_state *crtc_state,
@@ -1892,7 +1892,7 @@ struct intel_dpll_mgr {
 			      struct intel_dpll_hw_state *hw_state);
 };
 
-static const struct dpll_info pch_plls[] = {
+static const struct intel_dpll_info pch_plls[] = {
 	{ "PCH DPLL A", DPLL_ID_PCH_PLL_A, &ibx_pch_dpll_funcs, 0 },
 	{ "PCH DPLL B", DPLL_ID_PCH_PLL_B, &ibx_pch_dpll_funcs, 0 },
 	{ NULL, -1, NULL, 0 },
@@ -1904,7 +1904,7 @@ static const struct intel_dpll_mgr pch_pll_mgr = {
 	.dump_hw_state = ibx_dump_hw_state,
 };
 
-static const struct dpll_info hsw_plls[] = {
+static const struct intel_dpll_info hsw_plls[] = {
 	{ "WRPLL 1",    DPLL_ID_WRPLL1,     &hsw_ddi_wrpll_funcs, 0 },
 	{ "WRPLL 2",    DPLL_ID_WRPLL2,     &hsw_ddi_wrpll_funcs, 0 },
 	{ "SPLL",       DPLL_ID_SPLL,       &hsw_ddi_spll_funcs,  0 },
@@ -1920,7 +1920,7 @@ static const struct intel_dpll_mgr hsw_pll_mgr = {
 	.dump_hw_state = hsw_dump_hw_state,
 };
 
-static const struct dpll_info skl_plls[] = {
+static const struct intel_dpll_info skl_plls[] = {
 	{ "DPLL 0", DPLL_ID_SKL_DPLL0, &skl_ddi_dpll0_funcs, INTEL_DPLL_ALWAYS_ON },
 	{ "DPLL 1", DPLL_ID_SKL_DPLL1, &skl_ddi_pll_funcs,   0 },
 	{ "DPLL 2", DPLL_ID_SKL_DPLL2, &skl_ddi_pll_funcs,   0 },
@@ -1934,7 +1934,7 @@ static const struct intel_dpll_mgr skl_pll_mgr = {
 	.dump_hw_state = skl_dump_hw_state,
 };
 
-static const struct dpll_info bxt_plls[] = {
+static const struct intel_dpll_info bxt_plls[] = {
 	{ "PORT PLL A", DPLL_ID_SKL_DPLL0, &bxt_ddi_pll_funcs, 0 },
 	{ "PORT PLL B", DPLL_ID_SKL_DPLL1, &bxt_ddi_pll_funcs, 0 },
 	{ "PORT PLL C", DPLL_ID_SKL_DPLL2, &bxt_ddi_pll_funcs, 0 },
@@ -2368,7 +2368,7 @@ static const struct intel_shared_dpll_funcs cnl_ddi_pll_funcs = {
 	.get_hw_state = cnl_ddi_pll_get_hw_state,
 };
 
-static const struct dpll_info cnl_plls[] = {
+static const struct intel_dpll_info cnl_plls[] = {
 	{ "DPLL 0", DPLL_ID_SKL_DPLL0, &cnl_ddi_pll_funcs, 0 },
 	{ "DPLL 1", DPLL_ID_SKL_DPLL1, &cnl_ddi_pll_funcs, 0 },
 	{ "DPLL 2", DPLL_ID_SKL_DPLL2, &cnl_ddi_pll_funcs, 0 },
@@ -2391,7 +2391,7 @@ void intel_shared_dpll_init(struct drm_device *dev)
 {
 	struct drm_i915_private *dev_priv = to_i915(dev);
 	const struct intel_dpll_mgr *dpll_mgr = NULL;
-	const struct dpll_info *dpll_info;
+	const struct intel_dpll_info *dpll_info;
 	int i;
 
 	if (IS_CANNONLAKE(dev_priv))
@@ -2415,7 +2415,7 @@ void intel_shared_dpll_init(struct drm_device *dev)
 	for (i = 0; dpll_info[i].id >= 0; i++) {
 		WARN_ON(i != dpll_info[i].id);
 		memcpy(&dev_priv->shared_dplls[i].info, &dpll_info[i],
-		       sizeof(struct dpll_info));
+		       sizeof(struct intel_dpll_info));
 	}
 
 	dev_priv->dpll_mgr = dpll_mgr;
diff --git a/drivers/gpu/drm/i915/intel_dpll_mgr.h b/drivers/gpu/drm/i915/intel_dpll_mgr.h
index 4f21fb9108b5..e7ff45c11242 100644
--- a/drivers/gpu/drm/i915/intel_dpll_mgr.h
+++ b/drivers/gpu/drm/i915/intel_dpll_mgr.h
@@ -206,9 +206,9 @@ struct intel_shared_dpll_funcs {
 };
 
 /**
  * struct dpll_info - display PLL platform specific info
  */
-struct dpll_info {
+struct intel_dpll_info {
 	/**
 	 * @name: DPLL name; used for logging
 	 */
@@ -258,7 +258,7 @@ struct intel_shared_dpll {
 	/**
 	 * @info: platform specific info
 	 */
-	struct dpll_info info;
+	struct intel_dpll_info info;
 };
 
 #define SKL_DPLL0 0
@@ -206,9 +206,9 @@ struct intel_shared_dpll_funcs {
 
 /**
- * struct dpll_info - display PLL platform specific info
+ * struct intel_dpll_info - display PLL platform specific info
  */
-- 
2.14.3

_______________________________________________
Intel-gfx mailing list
Intel-gfx@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/intel-gfx

  parent reply	other threads:[~2018-03-20  6:25 UTC|newest]

Thread overview: 15+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2018-03-20  6:24 [PATCH 0/7] drm/i915: move dpll_info inside intel_shared_dpll Lucas De Marchi
2018-03-20  6:24 ` [PATCH 1/7] drm/i915: move dpll_info to header Lucas De Marchi
2018-03-20  9:56   ` Ville Syrjälä
2018-03-20 21:50     ` Lucas De Marchi
2018-03-21 10:25       ` Ville Syrjälä
2018-03-21 19:21         ` Lucas De Marchi
2018-03-20  6:24 ` [PATCH 2/7] drm/i915: embed dpll_info inside intel_shared_dpll Lucas De Marchi
2018-03-20  6:24 ` [PATCH 3/7] drm/i915: use funcs from dpll_info embedded in intel_shared_dpll Lucas De Marchi
2018-03-20  6:24 ` [PATCH 4/7] drm/i915: use name " Lucas De Marchi
2018-03-20  6:24 ` [PATCH 5/7] drm/i915: use id " Lucas De Marchi
2018-03-20  6:24 ` [PATCH 6/7] drm/i915: use flags " Lucas De Marchi
2018-03-20  6:24 ` Lucas De Marchi [this message]
2018-03-20  6:40 ` ✗ Fi.CI.CHECKPATCH: warning for drm/i915: move dpll_info inside intel_shared_dpll Patchwork
2018-03-20  6:57 ` ✗ Fi.CI.BAT: failure " Patchwork
2018-03-20  9:57 ` [PATCH 0/7] " Ville Syrjälä

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20180320062423.9166-8-lucas.demarchi@intel.com \
    --to=lucas.demarchi@intel.com \
    --cc=intel-gfx@lists.freedesktop.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.